@@ -14,9 +14,9 @@ class DriverInfo:
     schema: str
     ops: List[str]
     state: Any
-    dispatch: Callable[[str]]
+    dispatch: Callable[[str], None]
 
-    def __init__(self, driver: str, schema: str, ops: List[str], state: Any, dispatch: Callable[[str]]):
+    def __init__(self, driver: str, schema: str, ops: List[str], state: Any, dispatch: Callable[[str], None]):
         self.driver = driver
         self.schema = schema
         self.ops = ops
